==> dshell-1.8.3.tar.gz: lib/dshell.dart <==
export 'package:args/args.dart';
export 'src/functions/ask.dart' show ask, confirm;
export 'src/functions/cat.dart' show cat, CatException;
export 'src/functions/cd.dart' show CDException;
export 'src/script/dart_sdk.dart' show DartSdk;
export 'src/functions/chmod.dart' show chmod, ChModException;
export 'src/functions/copy.dart' show copy, CopyException;
export 'src/functions/delete.dart' show delete, DeleteException;
export 'src/functions/echo.dart' show echo;
export 'src/functions/env.dart' show env, HOME, PATH, isOnPath, setEnv, envs;
export 'src/functions/fileList.dart' show fileList;
export 'src/util/file_sync.dart';
export 'src/util/dshell_exception.dart';

export 'src/functions/find.dart' show find;
export 'src/functions/head.dart' show head;
export 'src/functions/is.dart' show isFile, isDirectory, exists;
export 'src/functions/create_dir.dart' show createDir, CreateDirException;
export 'src/functions/menu.dart' show menu;
export 'src/functions/move.dart' show move, MoveException;
export 'src/functions/replace.dart' show replace;
export 'src/util/dev_null.dart' show devNull;
export 'src/util/editor.dart' show showEditor;
export 'src/util/file_sort.dart' show FileSort, Column;
export 'src/util/process_helper.dart' show ProcessHelper;

export 'package:path/path.dart'
    hide
        PathMap,
        PathSet,
        Style,
        Context,
        context,
        posix,
        style,
        url,
        windows,
        hash,
        prettyUri,
        toUri,
        fromUri,
        current;
export 'src/functions/pop.dart' show PopException;
export 'src/functions/push.dart' show PushException;
export 'src/functions/pwd.dart' show pwd;
export 'src/functions/read.dart' show read, readStdin, ReadException;
export 'src/functions/delete_dir.dart' show deleteDir, DeleteDirException;
export 'src/functions/sleep.dart' show sleep;
export 'src/settings.dart' show Settings;
export 'src/functions/run.dart' show start;
export 'src/functions/touch.dart' show touch, TouchException;
export 'src/functions/which.dart' show which;
export 'src/util/shell.dart'
    show ShellDetection, Shell, BashShell, ZshShell, UnknownShell;
export 'src/util/runnable_process.dart' show printerr;
export 'src/util/string_as_process.dart';
export 'src/util/truepath.dart' show truepath;
export 'src/util/ansi_color.dart' hide AnsiColor;

==> dshell-1.8.4-dev.8.tar.gz: lib/dshell.dart <==
export 'package:args/args.dart';
export 'src/functions/ask.dart' show ask, confirm;
export 'src/functions/cat.dart' show cat, CatException;
export 'src/functions/cd.dart' show CDException;
export 'src/script/dart_sdk.dart' show DartSdk;
export 'src/functions/chmod.dart' show chmod, ChModException;
export 'src/functions/copy.dart' show copy, CopyException;
export 'src/functions/delete.dart' show delete, DeleteException;
export 'src/functions/echo.dart' show echo;
export 'src/functions/env.dart' show env, HOME, PATH, isOnPath, setEnv, envs;
export 'src/functions/fileList.dart' show fileList;
export 'src/util/file_sync.dart';
export 'src/util/dshell_exception.dart';

export 'src/functions/find.dart' show find;
export 'src/functions/head.dart' show head;
export 'src/functions/is.dart' show isFile, isDirectory, exists;
export 'src/functions/create_dir.dart' show createDir, CreateDirException;
export 'src/functions/menu.dart' show menu;
export 'src/functions/move.dart' show move, MoveException;
export 'src/functions/replace.dart' show replace;
export 'src/functions/tail.dart' show tail;
export 'src/util/dev_null.dart' show devNull;
export 'src/util/dshell_paths.dart' show DShellPaths;
export 'src/util/editor.dart' show showEditor;
export 'src/util/file_sort.dart' show FileSort, Column;
export 'src/util/process_helper.dart' show ProcessHelper;
export 'src/util/wait_for_ex.dart' show waitForEx;

export 'package:path/path.dart'
    hide
        PathMap,
        PathSet,
        Style,
        Context,
        context,
        posix,
        style,
        url,
        windows,
        hash,
        prettyUri,
        toUri,
        fromUri,
        current;
export 'src/functions/pop.dart' show PopException;
export 'src/functions/push.dart' show PushException;
export 'src/functions/pwd.dart' show pwd;
export 'src/functions/read.dart' show read, readStdin, ReadException;
export 'src/functions/delete_dir.dart' show deleteDir, DeleteDirException;
export 'src/functions/sleep.dart' show sleep;
export 'src/settings.dart' show Settings;
export 'src/functions/run.dart' show run, start, startFromArgs;
export 'src/functions/touch.dart' show touch, TouchException;
export 'src/functions/which.dart' show which;

export 'src/util/ansi_color.dart' hide AnsiColor;
export 'src/util/progress.dart' show Progress;
export 'src/util/shell.dart'
    show ShellDetection, Shell, BashShell, ZshShell, UnknownShell;
export 'src/util/runnable_process.dart' show printerr;
export 'src/util/string_as_process.dart';
export 'src/util/truepath.dart' show truepath, rootPath;
